**********
Snoweb SVG
**********

.. image:: https://img.shields.io/pypi/v/snowebsvg
    :target: https://pypi.org/project/snowebsvg/

.. image:: https://img.shields.io/pypi/pyversions/snowebsvg
    :target: https://pypi.org/project/snowebsvg/

.. image:: https://readthedocs.org/projects/snoweb-svg/badge/?version=latest
    :target: https://snoweb-svg.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/Aleksi44/snoweb-svg/badge.svg?branch=master
    :target: https://coveralls.io/github/Aleksi44/snoweb-svg?branch=master

.. image:: https://static.snoweb.fr/documents/logo-secondary.svg

Snoweb SVG is an open source project with SVGs optimized and animated built in HTML and CSS.


Features
********

- Animation on hover
- Theme dark and light
- SVG code in Html and Css
- No javascript required
- Possible integration with Django

Find all Svg at : `svg.snoweb.fr <https://svg.snoweb.fr>`_.

Documentation available : `here <https://snoweb-svg.readthedocs.io/en/latest/>`_.
